var path = require('path');
var HtmlWebpackPlugin = require('html-webpack-plugin');
var minimist = require('minimist');
var knownOptions = {
  string: 'env',
  default: {env: process.env.NODE_ENV || 'development'}
};
var options = minimist(process.argv.slice(2), knownOptions);
var isProduction = (options.env === 'production');

console.log('[build env]', options.env, '[is production]', isProduction);

module.exports = {
  entry: {
    app: isProduction ? './src/bootstrap/index.js' : './src/app.js'
  },
  output: {
    filename: '[name].js',
    path: './dest',
    chunkFilename: '[id].chunk.js'
  },
  module: {
    loaders: [
      {test: /\.js$/, loader: 'babel?presets[]=es2015', include: path.resolve('src')},
      {
        test: /\.sass$/,
        loaders: [
          'style',
          'css?sourceMap&modules&localIdentName=[name]__[local]___[hash:base64:5]',
          'sass'
        ]
      },
      {test: /\.(png|woff|woff2|eot|ttf|svg)$/, loader: 'url-loader?limit=100000'},
      {test: /\.html$/, loader: 'ng-cache?prefix=[dir]/[dir]'}
    ],
    preLoaders: [{test: /\.js$/, loader: 'eslint', include: path.resolve('src')}]
  },
  plugins: [
    new HtmlWebpackPlugin({
      template: path.resolve('src', 'index.html'),
      inject: 'body'
    })
  ],
  devtool: 'eval-source-map',
  devServer: {
    historyApiFallback: true,
    stats: {
      chunkModules: false,
      colors: true
    },
    contentBase: './src'
  },
  eslint: {
    configFile: './src/.eslintrc'
  }
};
